enum NetworkPOSPrinterUnderline { none, single, double }
enum NetworkPOSPrinterJustification { left, center, right }
enum NetworkPOSPrinterFont { fontA, fontB }

class NetworkPOSPrinterTextSize {
  const NetworkPOSPrinterTextSize._internal(this.value);

  final int value;
  static const size1 = NetworkPOSPrinterTextSize._internal(1);
  static const size2 = NetworkPOSPrinterTextSize._internal(2);
  static const size3 = NetworkPOSPrinterTextSize._internal(3);
  static const size4 = NetworkPOSPrinterTextSize._internal(4);
  static const size5 = NetworkPOSPrinterTextSize._internal(5);
  static const size6 = NetworkPOSPrinterTextSize._internal(6);
  static const size7 = NetworkPOSPrinterTextSize._internal(7);
  static const size8 = NetworkPOSPrinterTextSize._internal(8);

  static int getSize(NetworkPOSPrinterTextSize width, NetworkPOSPrinterTextSize height) => 16 * (width.value - 1) + (height.value - 1);
}

class NetworkPOSPrinterStyle {
  final bool bold;
  final bool inverse;
  final NetworkPOSPrinterUnderline underline;
  final NetworkPOSPrinterJustification justification;
  final NetworkPOSPrinterTextSize height;
  final NetworkPOSPrinterTextSize width;
  final NetworkPOSPrinterFont font;
  final NetworkPOSCodeTable codeTable;

  const NetworkPOSPrinterStyle({
    this.bold = false,
    this.inverse = false,
    this.underline = NetworkPOSPrinterUnderline.none,
    this.justification = NetworkPOSPrinterJustification.left,
    this.height = NetworkPOSPrinterTextSize.size1,
    this.width = NetworkPOSPrinterTextSize.size1,
    this.font = NetworkPOSPrinterFont.fontA,
    this.codeTable,
  });
}

class NetworkPOSCodeTable {
  const NetworkPOSCodeTable._internal(this.value);

  final int value;

  /// PC437 - U.S.A., Standard Europe
  static const pc437 = NetworkPOSCodeTable._internal(0);

  /// Katakana
  static const katakana = NetworkPOSCodeTable._internal(1);

  /// PC850 Multilingual
  static const pc850 = NetworkPOSCodeTable._internal(2);

  /// PC860 - Portuguese
  static const pc860 = NetworkPOSCodeTable._internal(3);

  /// PC863 - Canadian-French
  static const pc863 = NetworkPOSCodeTable._internal(4);

  /// PC865 - Nordic
  static const pc865 = NetworkPOSCodeTable._internal(5);

  /// Western Europe
  static const westEur = NetworkPOSCodeTable._internal(6);

  /// Greek
  static const greek = NetworkPOSCodeTable._internal(7);

  /// PC737 - Greek
  static const pc737 = NetworkPOSCodeTable._internal(64);

  /// PC851 - Greek
  static const pc851 = NetworkPOSCodeTable._internal(65);

  /// PC869 - Greek
  static const pc869 = NetworkPOSCodeTable._internal(66);

  /// PC928 - Greek
  static const pc928 = NetworkPOSCodeTable._internal(67);

  /// PC866 - Cyrillic #2
  static const pc866 = NetworkPOSCodeTable._internal(17);

  /// PC852 - Latin2
  static const pc852 = NetworkPOSCodeTable._internal(18);

  /// WPC1252 - Latin1
  static const wpc1252 = NetworkPOSCodeTable._internal(71);

  /// Space page
  static const spacePage = NetworkPOSCodeTable._internal(255);
}
